@@ -157,6 +157,14 @@ class HttpTransport(Transport):
         )  # type: DefaultDict[Tuple[str, str], int]
         self._last_client_report_sent = time.time()
 
+        compresslevel = options.get("_experiments", {}).get(
+            "transport_zlib_compression_level"
+        )
+        self._compresslevel = 9 if compresslevel is None else int(compresslevel)
+
+        num_pools = options.get("_experiments", {}).get("transport_num_pools")
+        self._num_pools = 2 if num_pools is None else int(num_pools)
+
         self._pool = self._make_pool(
             self.parsed_dsn,
             http_proxy=options["http_proxy"],
@@ -165,11 +173,6 @@ class HttpTransport(Transport):
             proxy_headers=options["proxy_headers"],
         )
 
-        compresslevel = options.get("_experiments", {}).get(
-            "transport_zlib_compression_level"
-        )
-        self._compresslevel = 9 if compresslevel is None else int(compresslevel)
-
         from sentry_sdk import Hub
 
         self.hub_cls = Hub
@@ -439,7 +442,7 @@ class HttpTransport(Transport):
     def _get_pool_options(self, ca_certs):
         # type: (Optional[Any]) -> Dict[str, Any]
         return {
-            "num_pools": 2,
+            "num_pools": self._num_pools,
             "cert_reqs": "CERT_REQUIRED",
             "ca_certs": ca_certs or certifi.where(),
         }
